Class: Brightpearl::ContactCustomField

Inherits:
Resource
  • Object
show all
Defined in:
lib/brightpearl/resources/contact_custom_field.rb

Overview

Contact custom fields are the user-defined data held against Brightpearl contacts. Several data types are available. Custom fields are separated between Supplier contacts and Customer contacts, and may only be assigned to one of these groups. api-docs.brightpearl.com/contact/custom-field/index.html

Class Method Summary collapse

Methods inherited from Resource

send_request, to_query

Class Method Details

.get(contact_id) ⇒ Object



7
8
9
# File 'lib/brightpearl/resources/contact_custom_field.rb', line 7

def get(contact_id)
  send_request(path: "contact-service/contact/#{contact_id}/custom-field", method: :get)
end

.patch(contact_id, params) ⇒ Object



12
13
14
# File 'lib/brightpearl/resources/contact_custom_field.rb', line 12

def patch(contact_id, params)
  send_request(path: "contact-service/contact/#{contact_id}/custom-field", method: :patch, body: params)
end