Class: Brightpearl::Webhook
- Extended by:
- APIOperations::Delete, APIOperations::Get, APIOperations::Post
- Defined in:
- lib/brightpearl/resources/webhook.rb
Overview
Webhooks are used to define a ‘callback contract’ between Brightpearl and some third-party system. They specify the circumstances under which Brightpearl should send an HTTP message to the third-party system and the format of that message.
They are typically used to notify a remote server supporting some integration of a change in the state of a resource in a customer’s Brightpearl account. For example, a carrier integration will want to know when Goods-Out Notes are picked or packed.
Please read Brightpearl webhooks for more information on how and when to use webhooks. api-docs.brightpearl.com/integration/webhook/index.html
Class Method Summary collapse
Methods included from APIOperations::Get
Methods included from APIOperations::Post
Methods included from APIOperations::Delete
Methods inherited from Resource
Class Method Details
.resource_path ⇒ Object
14 15 16 |
# File 'lib/brightpearl/resources/webhook.rb', line 14 def resource_path "integration-service/webhook" end |